/* CoolWorx Install program */

#include <windows.h>
#include <prsht.h>     /* could change */
#include "cwinstal.h"
#include "install.h"
#include <stdlib.h>

/* You must declare the title string */
char TITLE[]="CoolWorx Install";   // title

/* The code in this source file uses this string as
   a default */
#define DEFDIR "C:\\COOLWORX"


/* Subdirectories */
struct install_dirs subdirs[]=
  {
  {1,"SDI"},
  {2,"MDI"}
  };

/* Number of subdirectories */
#define NRDIRS sizeof(subdirs)/sizeof(subdirs[0])

/* File list. If srcfile is NULL install will prompt
   for disk change using flags as disk number --
   verify that diskN.id file exists on it.

   If dstdir is WINDIR, then use Windows directory
   if dstdir is SYSDIR, then use System directory

   If dstdir is ".", then use default install directory

   If flags are -1 then force straight copy
     (no decompress, etc.) */
struct _inst_files inst_files[]=
  {
     { 0,NULL,NULL,NULL,1,0 },
     { 0,"README.TXT",NULL,".",0,0 },
     { 0,"COOLWORX.DLL",NULL,WINDIR,VFFF_ISSHAREDFILE,0},
     { 0,"CBUTTON.DLL",NULL,WINDIR,VFFF_ISSHAREDFILE,0},
     { 0,"CWMISC.DLL",NULL,WINDIR,VFFF_ISSHAREDFILE,0},
     { 2,"COOLEDIT.EXE",NULL,"MDI",0,0},
     { 1,"SDIEDIT.EXE",NULL,"SDI",0,0}
  };

/* Number of files */
#define NRFILES (sizeof(inst_files)/sizeof(inst_files[0]))

char appdir[_MAX_PATH];
char opts[2];


/* 1st tab dialog proc */
BOOL pg1proc(HWND dlg,UINT cmd,WPARAM wParam,LPARAM lParam)
  {
  switch (cmd)
    {
    case WM_INITDIALOG:
      SetDlgItemText(dlg,DIR,DEFDIR);
      break;

    case WM_NOTIFY:
       {
       LPNMHDR nh=(LPNMHDR)lParam;
       switch (nh->code)
        {
/* Cancel */
        case PSN_RESET:
          EndDialog(dlg,FALSE);
          return TRUE;

/* OK */
        case PSN_APPLY:
/* Return TRUE */
          SetWindowLong(dlg,DWL_MSGRESULT,TRUE);
          GetDlgItemText(dlg,DIR,appdir,sizeof(appdir));
          EndDialog(dlg,TRUE);
          return TRUE;
        }
      break;
      }
    }
  return FALSE;
  }

/* 2nd tab dialog proc */
BOOL pg2proc(HWND dlg,UINT cmd,WPARAM wParam,LPARAM lParam)
  {
  switch (cmd)
    {
    case WM_INITDIALOG:
/* Init state */
      SendDlgItemMessage(dlg,SDI,BM_SETCHECK,
        opts[0]=='X',0);
      SendDlgItemMessage(dlg,MDI,BM_SETCHECK,
        opts[1]=='X',0);
      break;

    case WM_NOTIFY:
       {
       LPNMHDR nh=(LPNMHDR)lParam;
       switch (nh->code)
         {
          case PSN_RESET:
            EndDialog(dlg,FALSE);
            return TRUE;

/* OK */
          case PSN_APPLY:
            SetWindowLong(dlg,DWL_MSGRESULT,TRUE);
            opts[0]=SendDlgItemMessage(dlg,SDI,
              BM_GETCHECK,0,0)?'X':' ';
            opts[1]=SendDlgItemMessage(dlg,MDI,
              BM_GETCHECK,0,0)?'X':' ';
            EndDialog(dlg,TRUE);
            return TRUE;
         }
      break;
      }
    }
  return FALSE;
  }


/* Your main install routine must be named install!
  w=main window handle
  hInst=instance handle of install program
  srcdir=source directory for install (e.g., a:\) */
install(HWND w,HANDLE hInst,LPSTR srcdir)
  {
  int i;
  DWORD bitmask;   /* option bitmask */
  char tmpfile[_MAX_PATH];
/* Tabbed dialog body */
  PROPSHEETPAGE pages[2]=
    {
      {sizeof(PROPSHEETPAGE),0,0,"PG1",
        NULL,NULL,(DLGPROC)pg1proc,0,NULL,NULL},
      {sizeof(PROPSHEETPAGE),0,0,"PG2",
        NULL,NULL,(DLGPROC)pg2proc,0,NULL,NULL}
    };
/* Tabbed dialog header */
  PROPSHEETHEADER psh={sizeof(PROPSHEETHEADER),
    PSH_PROPSHEETPAGE,NULL,NULL,NULL,
    "CoolWorx32 Install",
      2,0,pages };
/* Set defaults */
  lstrcpy(appdir,DEFDIR);
  opts[0]='X';
  opts[1]='X';
  psh.hInstance=pages[0].hInstance=
    pages[1].hInstance=hInst;
  psh.hwndParent=w;
/* Come here if install returns RETRY */
retry:
  if (!PropertySheet(&psh))
     {
/* Come here if install is cancelled */
cancelinst:
     MessageBox(w,"Installation Cancelled",
       NULL,MB_OK|MB_ICONSTOP);
     return 1;
     }
  UpdateWindow(w); /* make sure window updates */
  bitmask=0;
/* decode options to bitmask */
  for (i=0;i<sizeof(opts);i++)
    if (opts[i]=='X') bitmask|=1<<i;
/* Call installer -- pass main window, app directory and options */
  switch (cw_Install(w,appdir,bitmask,subdirs,
    NRDIRS,inst_files,NRFILES,0,FALSE))
    {
    case RETRY:
      goto retry;     // show options again
    case CANCEL:
      goto cancelinst;  // forget it
    }
/* success */
/* Set up INI file, groups, etc.*/
  if (opts[0]=='X'||opts[1]=='X')
    {
    cw_ProgManCmd("[CreateGroup(CoolWorx32 Alpha,)]");
    cw_ProgManCmd("[ShowGroup(CoolWorx32 Alpha,1)]");
    if (opts[0]=='X')
      {
      cw_ProgManCmd("[ReplaceItem(SDI Editor)]");
      wsprintf(tmpfile,
        "[AddItem(%s\\SDI\\SDIEDIT.EXE,SDI Editor,,,,,)]",
        appdir);
      cw_ProgManCmd(tmpfile);
      }
    if (opts[1]=='X')
      {
      cw_ProgManCmd("[ReplaceItem(CoolEdit)]");
      wsprintf(tmpfile,
        "[AddItem(%s\\MDI\\COOLEDIT.EXE,CoolEdit,,,,,)]",
        appdir);
      cw_ProgManCmd(tmpfile);
      }
    WinExec("WORDPAD README.TXT",SW_SHOW);
    MessageBox(w,"Installation Complete","Notice",
      MB_OK|MB_ICONEXCLAMATION);
    }
  }

