// SYSTEM.CPP (MOUSE.EXE)
// (C) 1994 Ahpah Software Inc.
// Description: Protected mode functions and interrupts.

#include <stdio.h>
#include <stdlib.h>
#include <alloc.h>
#include "defs.h"
#include "graph.h"
#include "system.h"

/* variables */
PEHANDLER sys_oldgp;
PIHANDLER sys_oldccprot, sys_oldcbreakprot, sys_oldcritprot;
REALPTR   sys_oldccreal, sys_oldcbreakreal, sys_oldcritreal;

/* sys_cbreak() is the new control break handler
 */
VOID INTERRUPT far sys_cbreak( REGS_BINT r )
    {
    if( r.ax )
	return;
    }

/* sys_cc() is the new control-c handler
 */
VOID INTERRUPT far sys_cc( REGS_BINT r )
    {
    if( r.ax )
	return;
    }

/* sys_critical() is the new critical error handler
 */
VOID INTERRUPT far sys_critical( REGS_BINT r )
    {
    r.ax = (r.ax & 0xFF00);
    }

/* sys_ender() will remove interrupts and exception handlers
 */
VOID sys_ender( VOID )
    {
    CALL DosSetExceptionHandler( 0x0D, sys_oldgp, NULL );
    CALL DosSetRealProtVec( 0x1B, sys_oldcbreakprot, sys_oldcbreakreal,
	 NULL, NULL );
    CALL DosSetRealProtVec( 0x23, sys_oldccprot, sys_oldccreal,
	 NULL, NULL );
    CALL DosSetRealProtVec( 0x24, sys_oldcritprot, sys_oldcritreal,
	 NULL, NULL );
    }

/* sys_gpfault() is the new protection fault message
 */
VOID INTERRUPT far sys_gpfault( EXCEP_FRAME ef )
    {
    gr_ender();
    printf( "Error: General protection fault.\n\n" );
    printf( "ERRORCODE=%04X  FLAGS=%04X\n",
	    ef.error_code, ef.ret_flags );
    printf( "AX=%04X  BX=%04X  CX=%04X  DX=%04X\n",
	    ef.ax, ef.bx, ef.cx, ef.dx );
    printf( "SI=%04X  DI=%04X  BP=%04X  DS=%04X  ES=%04X\n\n",
	    ef.si, ef.di, ef.bp, ef.ds, ef.es );
    exit( 1 );
    }

/* sys_starter() will initialize the system and protection functions
 */
VOID sys_starter()
    {
    CALL atexit( sys_ender );
    CALL DosSetExceptionHandler( 0x0D, sys_gpfault, &sys_oldgp );
    CALL DosSetPassToProtVec( 0x1B, sys_cbreak, &sys_oldcbreakprot,
	 &sys_oldcbreakreal );
    CALL DosSetPassToProtVec( 0x23, sys_cc, &sys_oldccprot,
	 &sys_oldccreal );
    CALL DosSetPassToProtVec( 0x24, sys_critical, &sys_oldcritprot,
	 &sys_oldcritreal );
    }




